@@ -35,11 +35,9 @@ void proccpuinfo_free(proccpuinfo *);
 
 int   proccpuinfo_get_arch();
 char *proccpuinfo_get_filename();
-char *proccpuinfo_get_format();
 
 void proccpuinfo_set_arch(int);
 void proccpuinfo_set_filename(char*);
-void proccpuinfo_set_format(char*);
 
 int proccpuinfo_decode_arch(char*);
 
